==> videogen_0.32.orig.tar.gz: videogen-0.32/cfg.tab.h <==
/* A Bison parser, made from cfg.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_CFG_TAB_H
# define BISON_CFG_TAB_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     T_INTEGER = 258,
     T_FLOAT = 259,
     T_BOOLEAN = 260,
     T_VERBOSE = 261,
     T_FBSET = 262,
     T_NVIDIA = 263,
     T_MODE = 264,
     T_MAX_DOTCLK = 265,
     T_MAX_HFREQ = 266,
     T_MAX_VFREQ = 267,
     T_DESIRED_VFREQ = 268,
     T_HVISIBLE = 269,
     T_VVISIBLE = 270,
     T_HFPORCH = 271,
     T_HBPORCH = 272,
     T_HSYNC = 273,
     T_VFPORCH = 274,
     T_VBPORCH = 275,
     T_VSYNC = 276
   };
#endif
#define T_INTEGER 258
#define T_FLOAT 259
#define T_BOOLEAN 260
#define T_VERBOSE 261
#define T_FBSET 262
#define T_NVIDIA 263
#define T_MODE 264
#define T_MAX_DOTCLK 265
#define T_MAX_HFREQ 266
#define T_MAX_VFREQ 267
#define T_DESIRED_VFREQ 268
#define T_HVISIBLE 269
#define T_VVISIBLE 270
#define T_HFPORCH 271
#define T_HBPORCH 272
#define T_HSYNC 273
#define T_VFPORCH 274
#define T_VBPORCH 275
#define T_VSYNC 276




#ifndef YYSTYPE
#line 45 "cfg.y"
typedef union {
	long int ival;		/* integer value */
	double fval;		/* floating point value */
	unsigned char bval;	/* boolean value */
} yystype;
/* Line 1281 of /usr/share/bison/yacc.c.  */
#line 88 "cfg.tab.h"
# define YYSTYPE yystype
#endif

extern YYSTYPE yylval;


#endif /* not BISON_CFG_TAB_H */

==> videogen_0.33.orig.tar.gz: videogen-0.33/cfg.tab.h <==
/* A Bison parser, made from cfg.y, by GNU bison 1.75.  */

/* Skeleton parser for Yacc-like parsing with Bison,
   Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002 Free Software Foundation, Inc.

   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 2, or (at your option)
   any later version.

   This program is distributed in the hope that it will be useful,
   but WITHOUT ANY WARRANTY; without even the implied warranty of
   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
   GNU General Public License for more details.

   You should have received a copy of the GNU General Public License
   along with this program; if not, write to the Free Software
   Foundation, Inc., 59 Temple Place - Suite 330,
   Boston, MA 02111-1307, USA.  */

/* As a special exception, when this file is copied by Bison into a
   Bison output file, you may use that output file without restriction.
   This special exception was added by the Free Software Foundation
   in version 1.24 of Bison.  */

#ifndef BISON_CFG_TAB_H
# define BISON_CFG_TAB_H

/* Tokens.  */
#ifndef YYTOKENTYPE
# define YYTOKENTYPE
   /* Put the tokens into the symbol table, so that GDB and other debuggers
      know about them.  */
   enum yytokentype {
     T_INTEGER = 258,
     T_FLOAT = 259,
     T_BOOLEAN = 260,
     T_VERBOSE = 261,
     T_FBSET = 262,
     T_NVIDIA = 263,
     T_MODE = 264,
     T_MAX_DOTCLK = 265,
     T_MAX_HFREQ = 266,
     T_MAX_VFREQ = 267,
     T_DESIRED_VFREQ = 268,
     T_HVISIBLE = 269,
     T_VVISIBLE = 270,
     T_HFPORCH = 271,
     T_HBPORCH = 272,
     T_HSYNC = 273,
     T_VFPORCH = 274,
     T_VBPORCH = 275,
     T_VSYNC = 276
   };
#endif
#define T_INTEGER 258
#define T_FLOAT 259
#define T_BOOLEAN 260
#define T_VERBOSE 261
#define T_FBSET 262
#define T_NVIDIA 263
#define T_MODE 264
#define T_MAX_DOTCLK 265
#define T_MAX_HFREQ 266
#define T_MAX_VFREQ 267
#define T_DESIRED_VFREQ 268
#define T_HVISIBLE 269
#define T_VVISIBLE 270
#define T_HFPORCH 271
#define T_HBPORCH 272
#define T_HSYNC 273
#define T_VFPORCH 274
#define T_VBPORCH 275
#define T_VSYNC 276




#ifndef YYSTYPE
#line 45 "cfg.y"
typedef union {
	long int ival;		/* integer value */
	double fval;		/* floating point value */
	unsigned char bval;	/* boolean value */
} yystype;
/* Line 1281 of /opt/RFWgnu/share/bison/yacc.c.  */
#line 88 "cfg.tab.h"
# define YYSTYPE yystype
#endif

extern YYSTYPE yylval;


#endif /* not BISON_CFG_TAB_H */
